namespace :admin do
  desc "Assign events_admin role to a user by email"
  task :make_events_admin, [ :email ] => :environment do |t, args|
    email = args[:email]

    if email.blank?
      puts "Error: Email is required."
      puts "Usage: rake admin:make_events_admin[user@example.com]"
      exit 1
    end

    user = User.find_by(email: email)

    if user.nil?
      puts "Error: User with email '#{email}' not found."
      exit 1
    end

    # Get the events_admin role
    admin_role = Role.find_by(name: "events_admin")

    if admin_role.nil?
      puts "Error: 'events_admin' role does not exist."
      exit 1
    end

    if user.has_role?("events_admin")
      puts "User '#{user.name}' already has the events_admin role."
    else
      user.roles << admin_role
      puts "Successfully assigned events_admin role to '#{user.name}' (#{user.email})."
    end
  end

  desc "List all events admin users"
  task list_events_admins: :environment do
    admin_role = Role.find_by(name: "events_admin")

    if admin_role.nil?
      puts "Error: 'events_admin' role does not exist."
      exit 1
    end

    admins = admin_role.users

    if admins.empty?
      puts "No users with events_admin rights found."
    else
      puts "Users with events_admin rights:"
      puts "------------------------------"
      admins.each do |admin|
        puts "#{admin.name} (#{admin.email || 'No email'})"
      end
    end
  end

  desc "Remove events_admin role from a user by email"
  task :remove_events_admin, [ :email ] => :environment do |t, args|
    email = args[:email]

    if email.blank?
      puts "Error: Email is required."
      puts "Usage: rake admin:remove_events_admin[user@example.com]"
      exit 1
    end

    user = User.find_by(email: email)

    if user.nil?
      puts "Error: User with email '#{email}' not found."
      exit 1
    end

    # Get the events_admin role
    admin_role = Role.find_by(name: "events_admin")

    if admin_role.nil?
      puts "Error: 'events_admin' role does not exist."
      exit 1
    end

    if !user.has_role?("events_admin")
      puts "User '#{user.name}' does not have the events_admin role."
    else
      user.roles.delete(admin_role)
      puts "Successfully removed events_admin role from '#{user.name}' (#{user.email})."
    end
  end
end
